@@ -1,4 +1,7 @@
-__version__ = '2.0.2'
+__version__ = '2.0.3'
+
+import logging
+logger = logging.getLogger(__name__)
 
 from .dataframe_mapper import DataFrameMapper  # NOQA
 from .features_generator import gen_features  # NOQA
